@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::PerlCritic;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::PerlCritic::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 use strict;
 use warnings;
@@ -13,9 +16,8 @@ our $VERSION = "0.001";
 
 use File::Temp qw(tempfile tempdir);
 use File::Copy::Recursive qw(dircopy);
-use File::ShareDir qw(module_dir);
+use File::ShareDir qw(dist_dir);
 use Time::HiRes qw(gettimeofday);
-use Benchmark::Perl::Formance::Cargo;
 
 our $count;
 our $recurse;
@@ -26,7 +28,7 @@ sub prepare {
         my ($options) = @_;
 
         my $dstdir = tempdir( CLEANUP => 1 );
-        my $srcdir = module_dir('Benchmark::Perl::Formance::Cargo')."/PerlCritic";
+        my $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/PerlCritic";
 
         print STDERR "# Prepare Perl::Critic sources in $dstdir ...\n" if $options->{verbose} >= 3;
         dircopy($srcdir, $dstdir);
@@ -95,11 +97,16 @@ sub main {
 
 1;
 
+
+
+__END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::PerlCritic - Run Perl::Critic on itself
+Benchmark::Perl::Formance::Plugin::PerlCritic
 
 =head1 SYNOPSIS
 
@@ -107,5 +114,20 @@ Run it as any other plugin.
 
   $ perl-formance --plugins=PerlCritic
 
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::PerlCritic - Run Perl::Critic on itself
+
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
