@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Shootout::knucleotide;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Shootout::knucleotide::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # COMMAND LINE:
 # /usr/bin/perl knucleotide.perl 0 < knucleotide-input25000000.txt
@@ -25,8 +28,7 @@ our $VERSION = "0.001";
 #                                                           #
 #############################################################
 
-use Benchmark::Perl::Formance::Cargo;
-use File::ShareDir qw(module_dir);
+use File::ShareDir qw(dist_dir);
 use Benchmark ':hireswallclock';
 
 our $PRINT = 0;
@@ -43,7 +45,7 @@ sub run
         $output = '';
         $threads = 2*num_cpus() || 1;
 
-        my $srcdir = module_dir('Benchmark::Perl::Formance::Cargo')."/Shootout";
+        my $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/Shootout";
         my $srcfile = "$srcdir/$infile";
         open my $INFILE, "<", $srcfile or die "Cannot read $srcfile";
 
@@ -128,7 +130,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Shootout::knucleotide
 
 =head1 NAME
 
@@ -138,3 +148,20 @@ Benchmark::Perl::Formance::Plugin::Shootout::knucleotide - Language shootout plu
 
 This plugin does some runs the "knucleotide" benchmark from the
 Language Shootout.
+
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
